@@ -2,7 +2,7 @@
 
 # pyrsr, A package providing relative spectral response functions for remote sensing instruments.
 #
-# Copyright (C) 2019-2021
+# Copyright (C) 2019-2022
 # - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 # - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
 #   Germany (https://www.gfz-potsdam.de/)
@@ -134,6 +134,42 @@ sensors = {
         'thermal': ['10', '11']
     },
 
+    'LDCM2': {
+        'satellite': 'Landsat-9',
+        'sensor': 'LDCM',
+        'LBA': ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11'],
+        'LBA_sorted': ['1', '2', '3', '8', '4', '5', '9', '6', '7', '10', '11'],
+        'LBA_after_AC': ['1', '2', '3', '4', '5', '6', '7'],
+        'pan': ['8'],
+        'thermal': ['10', '11']
+    },
+
+    'OLI_TIRS2': {
+        'satellite': 'Landsat-9',
+        'sensor': 'OLI_TIRS',
+        'LBA': ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11'],
+        'LBA_sorted': ['1', '2', '3', '8', '4', '5', '9', '6', '7', '10', '11'],
+        'LBA_after_AC': ['1', '2', '3', '4', '5', '6', '7'],
+        'pan': ['8'],
+        'thermal': ['10', '11']
+    },
+
+    'OLI2': {
+        'satellite': 'Landsat-9',
+        'sensor': 'OLI',
+        'LBA': ['1', '2', '3', '4', '5', '6', '7', '8', '9'],
+        'LBA_sorted': ['1', '2', '3', '8', '4', '5', '9', '6', '7'],
+        'LBA_after_AC': ['1', '2', '3', '4', '5', '6', '7'],
+        'pan': ['8']
+    },
+
+    'TIRS2': {
+        'satellite': 'Landsat-9',
+        'sensor': 'TIRS',
+        'LBA': ['10', '11'],
+        'thermal': ['10', '11']
+    },
+
     'SPOT1a': {
         'satellite': 'SPOT-1',
         'sensor': 'HRV1',
