@@ -3,7 +3,7 @@
 
 # pyrsr, A package providing relative spectral response functions for remote sensing instruments.
 #
-# Copyright (C) 2019-2021
+# Copyright (C) 2019-2022
 # - Daniel Scheffler (GFZ Potsdam, daniel.scheffler@gfz-potsdam.de)
 # - Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences Potsdam,
 #   Germany (https://www.gfz-potsdam.de/)
@@ -37,6 +37,9 @@ from pyrsr.sensorspecs import get_LayerBandsAssignment
 class TestRelativeSpectralResponse(unittest.TestCase):
     """Tests for `pyrsr.RelativeSpectralResponse` class."""
 
+    def test_Landsat9(self):
+        RelativeSpectralResponse(satellite='Landsat-9', sensor='OLI_TIRS')
+
     def test_Landsat8(self):
         RelativeSpectralResponse(satellite='Landsat-8', sensor='OLI_TIRS')
 
@@ -125,3 +128,8 @@ class Test_get_LayerBandsAssignment(unittest.TestCase):
         LBA = get_LayerBandsAssignment('Sentinel-2A', 'MSI', after_ac=True)
         self.assertEqual(len(LBA), 11)
         self.assertEqual(LBA, ['1', '2', '3', '4', '5', '6', '7', '8', '8A', '11', '12'])
+
+
+if __name__ == '__main__':
+    import pytest
+    pytest.main()
